@@ -12,7 +12,7 @@ app.config.FALLBACK_ERROR_FORMAT = "json"
 app.config.API_HOST = (
     f'{app.config.get("API_HOST", "127.0.0.1")}:{app.config.get("API_PORT", 8080)}'
 )
-app.config.API_BASEPATH = app.config.get("API_BASEPATH", "/")
+app.config.API_BASEPATH = app.config.get("API_BASEPATH")
 app.config.API_SCHEMES = app.config.get("API_SCHEMES", "http,https").split(",")
 app.config.API_LICENSE_NAME = "MIT"
 app.config.API_TITLE = "Signal Cli REST API"
@@ -30,4 +30,5 @@ def run():
         debug=app.config.get("DEBUG", False),
         workers=app.config.get("WORKERS", 1),
         access_log=app.config.get("ACCESS_LOG", False),
+        auto_reload=app.config.get("AUTO_RELOAD", False),
     )
