@@ -4,7 +4,6 @@ api blueprints group
 
 
 from sanic import Blueprint
-from sanic_openapi import openapi2_blueprint
 
 from signal_cli_dbus_rest_api.api.about import about_v1
 from signal_cli_dbus_rest_api.api.send import send_v1, send_v2
@@ -24,6 +23,5 @@ entrypoint = Blueprint.group(
     register,
     search_v1,
     verify,
-    openapi2_blueprint,
     url_prefix="/",
 )
