@@ -80,8 +80,9 @@ async def groups_for_number_get(request, number):  # pylint: disable=unused-argu
         return json(result, 200)
     # pylint: disable=broad-except
     except Exception as err:
-        logger.error(err)
-        return json({"error": err.__repr__()}, 400)
+        error = getattr(err, 'message', repr(err))
+        logger.error(error)
+        return json({"error": error}, 400)
 
 
 @group_details.get("/<number>/<groupid:path>", version=1)
@@ -125,5 +126,6 @@ async def groups_of_number_get(
         return json(data, 200)
     # pylint: disable=broad-except
     except Exception as err:
-        logger.error(err)
-        return json({"error": err.__repr__()}, 400)
+        error = getattr(err, 'message', repr(err))
+        logger.error(error)
+        return json({"error": error}, 400)
