@@ -58,8 +58,9 @@ def send_reaction(
         return {"timestamp": str(result)}, 201
     # pylint: disable=broad-except
     except Exception as err:
-        logger.error(err)
-        return {"error": err.__repr__()}, 400
+        error = getattr(err, 'message', repr(err))
+        logger.error(error)
+        return {"error": error}, 400
 
 
 @dataclass
