@@ -2,14 +2,15 @@
 register and verify
 """
 
-from typing import Optional
 from dataclasses import dataclass, field
+from typing import Optional
+
 from sanic import Blueprint
 from sanic.log import logger
 from sanic.response import json
 from sanic_ext import openapi, validate
-from signal_cli_dbus_rest_api.lib.dbus import SignalCLIDBus
 from signal_cli_dbus_rest_api.dataclasses import Error
+from signal_cli_dbus_rest_api.lib.dbus import SignalCLIDBus
 
 register = Blueprint("register", url_prefix="/register")
 verify = Blueprint("verify", url_prefix="/register")
@@ -20,10 +21,21 @@ class RegisterV1PostParams:
     """
     RegisterV1PostParams
     """
+
     captcha: Optional[str]
     use_voice: Optional[bool] = False
 
 
+@register.middleware("request")
+async def register_post_dummy_body(request):
+    """
+    Create empty dummy body for @validate
+    if there is none in request
+    """
+    if not request.body:
+        request.body = b"{}"
+
+
 @register.post("/<number:path>", version=1)
 @openapi.tag("Devices")
 @openapi.parameter("number", str, required=True, location="path")
@@ -31,8 +43,10 @@ class RegisterV1PostParams:
 @openapi.response(201, {"application/json": None}, description="Created")
 @openapi.response(400, {"application/json": Error}, description="Bad Request")
 @openapi.description("Register a phone number with the signal network.")
-@validate(json=RegisterV1PostParams)
-async def register_post(request, number, body: RegisterV1PostParams):  # pylint: disable=unused-argument
+@validate(RegisterV1PostParams)
+async def register_post(
+    request, number, body: RegisterV1PostParams
+):  # pylint: disable=unused-argument
     """
     Register a phone number.
     """
@@ -54,8 +68,9 @@ async def register_post(request, number, body: RegisterV1PostParams):  # pylint:
         return json(None, 200)
     # pylint: disable=broad-except
     except Exception as err:
-        logger.error(err)
-        return json({"error": err.__repr__()}, 400)
+        error = getattr(err, 'message', repr(err))
+        logger.error(error)
+        return json({"error": error}, 400)
 
 
 @dataclass
@@ -63,9 +78,20 @@ class VerifyV1PostParams:
     """
     VerifyV1PostParams
     """
+
     pin: Optional[str] = field(default_factory=str)
 
 
+@register.middleware("request")
+async def verify_post_dummy_body(request):
+    """
+    Create empty dummy body for @validate
+    if there is none in request
+    """
+    if not request.body:
+        request.body = b"{}"
+
+
 @verify.post("/<number:path>/verify/<token:path>", version=1)
 @openapi.tag("Devices")
 @openapi.parameter("number", str, required=True, location="path")
@@ -74,19 +100,19 @@ class VerifyV1PostParams:
 @openapi.response(201, {"application/json": None}, description="Created")
 @openapi.response(400, {"application/json": Error}, description="Bad Request")
 @openapi.description("Verify a registered phone number with the signal network.")
-async def verify_post(request, number, token):  # pylint: disable=unused-argument
+@validate(VerifyV1PostParams)
+async def verify_post(
+    request, number, token, body: VerifyV1PostParams
+):  # pylint: disable=unused-argument
     """
     Verify a registered phone number.
     """
-    pin = None
-    if request.json:
-        pin = request.json.get("pin")
     opts = [number, token]
     try:
         dbus = SignalCLIDBus()
-        if pin:
+        if body.pin:
             method = dbus.pydbusconn.verifyWithPin
-            opts.append(pin)
+            opts.append(body.pin)
         else:
             method = dbus.pydbusconn.verify
         result = method(*opts)
@@ -97,5 +123,6 @@ async def verify_post(request, number, token):  # pylint: disable=unused-argumen
         return json(None, 200)
     # pylint: disable=broad-except
     except Exception as err:
-        logger.error(err)
-        return json({"error": err.__repr__()}, 400)
+        error = getattr(err, 'message', repr(err))
+        logger.error(error)
+        return json({"error": error}, 400)
