@@ -78,8 +78,9 @@ def send_message(
         return {"timestamp": str(timestamp)}, 201
     # pylint: disable=broad-except
     except Exception as err:
-        logger.error(err)
-        return {"error": err.__repr__()}, 400
+        error = getattr(err, 'message', repr(err))
+        logger.error(error)
+        return {"error": error}, 400
     finally:
         for attachment in attachments:
             os_remove(attachment)
@@ -113,7 +114,7 @@ class SendV2PostResponse:
 @openapi.response(201, {"application/json": SendV2PostResponse}, description="Created")
 @openapi.response(400, {"application/json": Error}, description="Bad Request")
 @openapi.description("Send a signal message.")
-@validate(json=SendV2PostParams)
+@validate(SendV2PostParams)
 async def send_v2_post(request, body: SendV2PostParams):  # pylint: disable=unused-argument
     """
     Send a signal message.
@@ -170,7 +171,7 @@ class SendV1PostResponse:
 @openapi.response(201, {"application/json": SendV1PostResponse}, description="Created")
 @openapi.response(400, {"application/json": Error}, description="Bad Request")
 @openapi.description("Send a signal message.")
-@validate(query=SendV1PostParams)
+@validate(SendV1PostParams)
 async def send_v1_post(request, recipient, body: SendV1PostParams):  # pylint: disable=unused-argument
     """
     Send a signal message.
